
#ifndef __BPNGLOGGERDETECTOR_HH__
#define __BPNGLOGGERDETECTOR_HH__

#include "IBPNGClient.h"
#include "IBPNGClientListener.h"

#include <vector>
#include <string>

// this struct matches the OnlineLoggerInfo but uses STL strings
struct BP2Device
{
    BP2Device()
    {
	ipAddress = "";
	mainboardNr = "";
	name = "";
	connected = false;
	connectedUser = "";
	status = 0;
    }

    BP2Device(OnlineLoggerInfo* logger)
    {
	if (logger != 0)
	{
	    ipAddress = logger->ip;
	    mainboardNr = logger->mbnr;
	    name = logger->name;
	    connected = logger->connected != 0;
	    connectedUser = logger->currentUser;
	    status = logger->loggerStatus;
	}
    }

    std::string ipAddress;
    std::string name;
    std::string mainboardNr;
    bool connected;
    std::string connectedUser;
    int status;
};

class BPNGLoggerDetector : public IBPNGClientListener
{
public:
    // COnstructor
    BPNGLoggerDetector();

    // Returns a vector of BP2Devices, search the network for searchTimeOut seconds
    std::vector<BP2Device> getLoggerList(unsigned searchTimeOut);

    // listener function for observing blue PiraT 2 devices in network
    virtual void WINAPI onBPNGDeviceDetected(OnlineLoggerInfo* info);
    virtual void WINAPI onBPNGDeviceDisappeared(OnlineLoggerInfo* info);
    virtual void WINAPI onBPNGDeviceStateChange(OnlineLoggerInfo* info);

    // listener function not needed by BPNGLoggerDetector
    virtual int WINAPI onProgressDataDownload(int percentCompleted)
    {
	return 1;
    }
    virtual int WINAPI onProgressConversion(int percentCompleted, const char* status)
    {
	return 1;
    }
    virtual void WINAPI onStatusMessage(const char* statusMsg) {}
    virtual void WINAPI onWarning(BPNGWarningCode warningCode, const char* warnMsg) {}
    virtual int WINAPI onTargetPathTooLong(char* newTarget, int maxSize)
    {
	return 0;
    }
    virtual int WINAPI getOverwritingPermission(const char* filePath)
    {
	return 1;
    }
    virtual int WINAPI onCriticalDiskSpace(uint64_t freeSpace, uint64_t neededSpace, const char* drive)
    {
	return 1;
    }
    virtual void WINAPI onFirmwareUpdateProgress(int percentage, int stepId, int subStepId, const char* desc) {}
    virtual void WINAPI onFirmwareUpdateError(int  errorId) {}
    virtual int WINAPI onGetLogReportProgress(int percentage, const char* desc)
    {
	return 1;
    }
    virtual int WINAPI onCriticalDiskSpace(uint64_t freeSpace, uint64_t neededSpace, const char* drive, const char* msg)
    {
	return 1;
    }


private:
    std::vector<BP2Device> m_loggerList;
};

#endif // __BPNGLOGGERDETECTOR_HH__
